# gmalg

GM algorithms implemented in pure python.

It has low computational performance and is only used to experience and learn GM algorithms.

## Install

```bat
pip install gmalg
```

## Implemented Core Algorithms

- [x] ZUC Stream Cipher Algorithm
- [ ] Public Key Cryptograhpic Algorithm SM2 Based on Elliptic Curves
- [x] SM3 Cryptogrpahic Hash Algorithm
- [x] SM4 Block Cipher Algorithm
- [ ] SM9 Identification Cryptographic Algorithm

## API

TODO

---

*If you think this project is helpful to you, :star: it and let more people see!*
